EncodingError

Enum EncodingError 

#[non_exhaustive]
pub enum EncodingError { DimensionTooLarge(usize), EmptyVector, Malformed { dim: u16, bytes: usize, }, CodecMismatch { expected: Codec, got: Codec, }, NonFinite, UnsupportedBitWidth(u8), UnsupportedDim(u16), }
Errors returned by encoders.

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


DimensionTooLarge(usize)

Vector dimension count cannot be represented as u16.



EmptyVector

Vector dimension count is zero.



Malformed

The encoded payload’s length does not match the codec’s expectation for the recorded dimension.

Fields

dim: u16

Recorded dimension count.

bytes: usize

Actual payload byte count.



CodecMismatch

The codec identifier on the EncodedVector does not match the encoder being asked to decode it.

Fields

expected: Codec

Encoder’s codec.

got: Codec

Codec recorded on the EncodedVector.



NonFinite

Component value was non-finite (NaN, +inf, -inf). The codecs reject these so the reconstruction error budget is well-defined.



UnsupportedBitWidth(u8)

bit_width parameter outside the supported range. The turbovec codec accepts only 2, 3, or 4.



UnsupportedDim(u16)

Vector dimension is incompatible with the requested codec. The turbovec codec requires dim to be a positive multiple of 8.